package net.wanji.opt.dto.strategy;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Range;

import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/2/27 11:31
 */
@NoArgsConstructor
@Data
@ApiModel(value = "AddOrUpdateSceneDTO", description = "策略管理-场景库-新增/修改场景")
public class AddOrUpdateSceneDTO {
    @ApiModelProperty(value = "场景ID（不传ID为新增，传ID为修改）",notes = "")
    private Integer id;
    @ApiModelProperty(value = "编号",required = true, notes = "")
    @Pattern(regexp = "^[\\u4E00-\\u9FA5\\w\\-]{0,16}$", message = "编号只能包含中文、英文、数字、下划线和中横线,0~16个字符")
    private String sceneCode;
    @ApiModelProperty(value = "场景代码 0正常 1失衡 2拥堵 3溢出",required = false, notes = "")
    private Integer sceneNum;
    @ApiModelProperty(value = "场景名称",required = true, notes = "")
    @Pattern(regexp = "^[\\u4E00-\\u9FA5\\w\\-]{0,50}$", message = "场景名称只能包含中文、英文、数字、下划线和中横线,0~50个字符")
    private String sceneName;
    @ApiModelProperty(value = "应用对象 1路口；2干线；3区域",required = true,notes = "")
    private Integer secneTarget;
    @ApiModelProperty(value = "应用策略",required = true,notes = "")
    @Valid
    @NotEmpty(message = "策略不可为空")
    private List<StrategyListElement> strategyList;

    @NoArgsConstructor
    @Data
    public static class StrategyListElement {
        @ApiModelProperty(value = "策略ID",required = true,notes = "")
        private Integer id;
        @ApiModelProperty(value = "策略名称",required = true,notes = "")
        private String strategyName;
        @ApiModelProperty(value = "优先级",required = true,notes = "")
        @NotNull(message = "优先级不可为空")
        @Range(min = 1, max = 99, message = "优先级为1至99数字")
        private Integer priority;
        @ApiModelProperty(value = "优化方法",required = true,notes = "")
        @NotEmpty(message = "方法不可为空")
        private List<IdeaListElement> ideaList;

    }
    @NoArgsConstructor
    @Data
    public static class IdeaListElement {
        @ApiModelProperty(value = "方法ID",required = true,notes = "")
        private Integer id;
        @ApiModelProperty(value = "方法名称",required = true,notes = "")
        private String ideaName;
        @ApiModelProperty(value = "返回顺序",required = true,notes = "")
        private Integer order;
    }
}
